@@ -13,17 +13,22 @@
 #include <DApplication>
 #include <DGuiApplicationHelper>
 #include <DLog>
+#include <QLoggingCategory>
 
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 
+Q_LOGGING_CATEGORY(logUpdateModal, "dde.update.modalupdate")
+
 DCORE_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
 int main(int argc, char *argv[])
 {
+    qCInfo(logUpdateModal) << "Starting dde-update application";
     if (!QString(qgetenv("XDG_CURRENT_DESKTOP")).toLower().startsWith("deepin")) {
         setenv("XDG_CURRENT_DESKTOP", "Deepin", 1);
+        qCDebug(logUpdateModal) << "Set XDG_CURRENT_DESKTOP to Deepin";
     }
 
     DGuiApplicationHelper::setAttribute(DGuiApplicationHelper::UseInactiveColorGroup, false);
@@ -44,10 +49,12 @@ int main(int argc, char *argv[])
     app->setApplicationName("dde-update");
     app->setApplicationVersion("2015.1.0");
 
+    qCDebug(logUpdateModal) << "Setting up DLog format and appenders";
     DLogManager::setLogFormat("%{time}{yyyy-MM-dd, HH:mm:ss.zzz} [%{type:-7}] [ %{function:-35} %{line}] %{message}\n");
     DLogManager::registerConsoleAppender();
     DLogManager::registerJournalAppender();
 
+    qCDebug(logUpdateModal) << "Setting up command line options";
     QCommandLineOption doUpgrade(QStringList() << "u" << "do-upgrade", "Do upgrade, backup system and install packages.");
     QCommandLineOption checkSystem(QStringList() << "c" << "check-upgrade", "Check if the update was successful.");
     QCommandLineOption checkSystemBeforeLogin(QStringList() << "b" << "before-login", "Check system before login.");
@@ -80,17 +87,21 @@ int main(int argc, char *argv[])
     DGuiApplicationHelper::generatePaletteColor(pa, DPalette::ButtonText, DGuiApplicationHelper::LightType);
     DGuiApplicationHelper::instance()->setApplicationPalette(pa);
 
+    qCDebug(logUpdateModal) << "Loading translation for locale:" << getCurrentLocale();
     QTranslator translatorLanguage;
     if (!translatorLanguage.load("/usr/share/deepin-update-ui/translations/dde-update_" + getCurrentLocale())) {
-        qWarning() << "Failed to load translation file for locale" << getCurrentLocale();
+        qCWarning(logUpdateModal) << "Failed to load translation file for locale" << getCurrentLocale();
     }
 
     app->installTranslator(&translatorLanguage);
 
+    qCDebug(logUpdateModal) << "Initializing UpdateWorker instance";
     UpdateWorker::instance()->init();
 
     const bool whetherDoUpgrade = UpdateModel::instance()->whetherDoUpgrade() || parser.isSet(doUpgrade);
+    qCDebug(logUpdateModal) << "Whether do upgrade:" << whetherDoUpgrade;
     if (whetherDoUpgrade) {
+        qCInfo(logUpdateModal) << "Showing update widget";
         UpdateWidget::instance()->showUpdate();
     } else {
         if (parser.isSet(checkSystem)) {
@@ -98,7 +109,7 @@ int main(int argc, char *argv[])
         }
 
         if (UpdateModel::instance()->checkSystemStage() == UpdateModel::CSS_None || UpdateModel::instance()->updateMode() <= 0) {
-            qWarning() << "Update options are invalid, check system stage:" << UpdateModel::instance()->checkSystemStage()
+            qCWarning(logUpdateModal) << "Update options are invalid, check system stage:" << UpdateModel::instance()->checkSystemStage()
                 << ", check update mode:" << UpdateModel::instance()->updateMode();
 
             return 1;
