@@ -1,37 +1,35 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="de">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
 <context>
     <name>CheckProgressWidget</name>
     <message>
         <source>The check is almost complete, thank you for your patience</source>
-        <translation type="unfinished"></translation>
+        <translation>Die Überprüfung ist fast beendet, Danke für Ihre Geduld</translation>
     </message>
     <message>
         <source>Preparing</source>
-        <translation type="unfinished"></translation>
+        <translation>Vorbereiten</translation>
     </message>
 </context>
 <context>
     <name>ErrorFrame</name>
     <message>
         <source>Checked for some errors</source>
-        <translation type="unfinished"></translation>
+        <translation>Auf einige Fehler überprüft</translation>
     </message>
 </context>
 <context>
     <name>SuccessFrame</name>
     <message>
         <source>Go to Desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Zum Schreibtisch wechseln</translation>
     </message>
     <message>
         <source>Welcome, system updated successfully</source>
-        <translation type="unfinished"></translation>
+        <translation>Willkommen, System erfolgreich aktualisiert</translation>
     </message>
     <message>
         <source>Current Edition:</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktuelle Version:</translation>
     </message>
 </context>
 <context>
@@ -50,34 +48,34 @@
     </message>
     <message>
         <source>The automatic reboot process has failed. Please try to manually reboot your device.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die automatische Neustart-Prozedur schlug fehl. Bitte versuchen Sie ihr Gerät selbst neuzustarten.</translation>
     </message>
     <message>
         <source>The automatic shutdown process has failed. Please try to manually shut down your device.</source>
-        <translation type="unfinished"></translation>
+        <translation>Die automatische erunterfahren-Prozedur schlug fehl. Bitte versuchen Sie ihr Gerät selbst herunterzufahren.</translation>
     </message>
     <message>
         <source>View update logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsprotokolle ansehen</translation>
     </message>
     <message>
         <source>Collapse update logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsprotokolle zuklappen</translation>
     </message>
 </context>
 <context>
     <name>UpdateLogWidget</name>
     <message>
         <source>Export</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportieren</translation>
     </message>
     <message>
         <source>The log has been exported to the desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Das Protokoll wurde auf den Schreibtisch gespeichert</translation>
     </message>
     <message>
         <source>Log export failed, please try again</source>
-        <translation type="unfinished"></translation>
+        <translation>Exportieren des Protokolls schlug fehl, bitte erneut versuchen</translation>
     </message>
 </context>
 <context>
@@ -104,11 +102,11 @@
     </message>
     <message>
         <source>Failed to connect to backup services. Please check and retry again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Datensicherungsdienste konnten nicht erreicht werden. Bitte überprüfen und erneut versuchen.</translation>
     </message>
     <message>
         <source>Failed to connect to update services. Please check and retry again.</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsdienste konnten nicht erreicht werden. Bitte überprüfen und erneut versuchen.</translation>
     </message>
     <message>
         <source>Dependency error</source>
@@ -128,7 +126,7 @@
     </message>
     <message>
         <source>Proceed to Update</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierung fortsetzen</translation>
     </message>
     <message>
         <source>Reboot</source>
@@ -140,7 +138,7 @@
     </message>
     <message>
         <source>Go to Desktop</source>
-        <translation type="unfinished"></translation>
+        <translation>Zum Schreibtisch wechseln</translation>
     </message>
 </context>
 <context>
@@ -158,18 +156,18 @@
     </message>
     <message>
         <source>View update logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsprotokolle ansehen</translation>
     </message>
     <message>
         <source>Collapse update logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsprotokolle zuklappen</translation>
     </message>
 </context>
 <context>
     <name>UpdateWorker</name>
     <message>
         <source>updatelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisierungsprotokoll</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
