@@ -167,7 +167,7 @@
     <name>UpdateWorker</name>
     <message>
         <source>updatelog</source>
-        <translation type="unfinished"/>
+        <translation>regjistër përditësimesh</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
