@@ -22,10 +22,12 @@ public:
     const QStringList &textList() { return  m_textList; }
     void setText(const QString &text);
     void setTextList(const QStringList &textList);
+    QSize sizeHint() const override;
 
 protected:
     void paintEvent(QPaintEvent *event) override;
     bool event(QEvent *event) override;
+    QSize minimumSizeHint() const override;
 
 private:
     QString m_text;
